#
# spec file for package libfwsi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libfwsi1
Name:           libfwsi
Version:        20240423
Release:        bp160.1.6
Summary:        Library to access the Windows Shell Item format
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libfwsi
Source:         https://github.com/libyal/libfwsi/releases/download/%version/%name-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libfwsi/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source3:        %name.keyring
Source9:        Windows_Shell_Item_format.pdf
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libfole) >= 20240415
BuildRequires:  pkgconfig(libfwps) >= 20240417
BuildRequires:  pkgconfig(libuna) >= 20240414
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
Library to access the Windows Shell Item format for the libyal family of libraries.
libyal is typically used in digital forensic tools.

%package -n %lname
Summary:        Library to access the Windows Shell Item format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
Library to access the Windows Shell Item format for the libyal family of libraries.
libyal is typically used in digital forensic tools.

%package devel
Summary:        Development files for libfwsi
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Library to access the Windows Shell Item format for the libyal family of libraries.  libyal is typically used in digital forensic tools.

This subpackage contains libraries and header files for developing
applications that want to make use of libfwsi.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* %buildroot/
find %buildroot -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libfwsi.so.*

%files -n %name-devel
%license COPYING*
%doc Windows_Shell_Item_format.pdf
%_includedir/libfwsi.h
%_includedir/libfwsi/
%_libdir/libfwsi.so
%_libdir/pkgconfig/libfwsi.pc
%_mandir/man3/libfwsi.3*

%files %python_files
%license COPYING*
%python_sitearch/pyfwsi.so

%changelog
* Tue Apr 23 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240423
  * No changelog was provided
* Wed Apr 17 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240417
  * Recognize more folder identifiers in shell items
* Mon Mar 18 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240315
  * Acronis True Image (TIB) file shell item support
* Fri Mar  1 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240301
  * Support different SWN1 signature
* Sun Feb 25 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240225
  * Added functions for notifications, delegate folder identifiers,
    control panel categories, control panel items, and
    user property views.
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Fri Dec  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231130
  * Build system updates only
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Wed Jul 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230710
  * No changelog was provided
* Mon Jan 30 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230114
  * No changelog was provided
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Sun Oct 23 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220907
  * No changelog was provided.
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220123
  * No changelog was provided.
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sun Jan 23 2022 Jan Engelhardt <jengelh@inai.de>
- (deleted entry because no-op change)
* Sat Jan 22 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds. (This reenables python2 for Leap 15)
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Drop python2 module build.
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210419 (4142a726)
  * No changelog was provided
- Add system-libs.patch
* Tue Dec 29 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201204
  * no documented changes
- added all COPYING* files to %%license line
* Tue Apr  7 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20191221
  * minor release
  * Worked on Python wheel support
- rename python-libfwsi to python2-libfwsi
- add python3 bindings submodule
* Mon Apr 15 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20181227
  * Changes to improve handling corrupt shell item lists
  * Worked on Python bindings
  * Changes to improve handling corrupt URI extension values
  * Fix for handling corrupt shell items
  * Changes to improve handling corrupt file entry extension values
  * Added URI sub values shell item type
  * Changes for debug output and unsuppored extension block sizes
  * Changes to URI and URI sub shell items
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to v0~20170117
* Tue Dec  1 2015 Greg.Freemyer@gmail.com
- update to v0~20150701
  * bug fix for shared usage
* Wed Jul  1 2015 Greg.Freemyer@gmail.com
- update to v0~20150614
  * bug fix for shared usage
  * changes for shell item being created outside of list
  * fix for missing libfwsi_notify_set_verbose
- make pyfwsi provide version info
- for the python sub-package add a Requires libfwsi
* Thu Jan 15 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on utility scripts
  * small fixes
  * worked on format support
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- remove %%if opensuse logic.  Not needed with libyal in security:forensics
- use libyal packages from OBS if available
* Mon Sep  1 2014 Greg.Freemyer@gmail.com
- initial package in OBS (v0~20140801)
